@@ -5,7 +5,7 @@ use warnings;
 use 5.008;
 use IPC::SysV qw(SEM_UNDO IPC_NOWAIT);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 ############
 ## Public ##
@@ -41,7 +41,7 @@ sub lockOrDie {
 
 sub lock     {return shift->_lock(SEM_UNDO | IPC_NOWAIT) ? 1 : 0}
 sub lockWait {return shift->_lock(SEM_UNDO)              ? 1 : 0}
-sub unlock   {return shift->_unlock(IPC_NOWAIT) ? 1 : 0}
+sub addValue {return shift->_add_value(IPC_NOWAIT) ? 1 : 0}
 
 ############
 ## Helper ##
@@ -54,7 +54,7 @@ sub available {
 
 sub number {return shift->{number}}
 sub set    {return shift->{set}}
-sub value  {return shift->{value}}
+sub value  {return shift->available}
 
 #############
 ## Private ##
@@ -63,24 +63,13 @@ sub value  {return shift->{value}}
 sub _lock
 {
 	my ($self, $flags) = @_;
-	my $lock = $self->set->sem->op($self->number, -1, $flags);
-	if ($lock) {
-		$self->{_locks}++;
-	}
-	return $lock;
+	return $self->set->sem->op($self->number, -1, $flags);
 }
 
-sub _unlock
+sub _add_value
 {
 	my ($self, $flags) = @_;
-	if ($self->{_locks} < 1) {
-		return 0;
-	}
-	my $unlock = $self->set->sem->op($self->number, 1, $flags);
-	if ($unlock) {
-		$self->{_locks}--;
-	}
-	return $unlock;
+	return $self->set->sem->op($self->number, 1, $flags);
 }
 
 1;
